#
# spec file for package perl-Text-Aligner
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Text-Aligner
Version:        0.16
Release:        1.19
%define cpan_name Text-Aligner
Summary:        Module to align text
License:        SUSE-Public-Domain
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.280000
BuildRequires:  perl(Term::ANSIColor) >= 2.02
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Term::ANSIColor) >= 2.02
%{perl_requires}

%description
Text::Aligner exports a single function, align(), which is used to justify
strings to various alignment styles. The alignment specification is the
first argument, followed by any number of scalars which are subject to
alignment.

The operation depends on context. In list context, a list of the justified
scalars is returned. In scalar context, the justified arguments are joined
into a single string with newlines appended. The original arguments remain
unchanged. In void context, in-place justification is attempted. In this
case, all arguments must be lvalues.

Align() also does one level of scalar dereferencing. That is, whenever one
of the arguments is a scalar reference, the scalar pointed to is aligned
instead. Other references are simply stringified. An undefined argument is
interpreted as an empty string without complaint.

Alignment respects colorizing escape sequences a la Term::ANSIColor which
means it knows that these sequences don't take up space on the screen.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Thu Apr 30 2020 Tina Müller <timueller+perl@suse.de>
  updated to 0.16
  see /usr/share/doc/packages/perl-Text-Aligner/Changes
  0.16  2020-04-29
  - Fix a $VERSION mismatch in lib/Text/Aligner.pm .
  - Thanks to "[Tux]".
* Wed Apr 29 2020 Tina Müller <timueller+perl@suse.de>
  updated to 0.15
  see /usr/share/doc/packages/perl-Text-Aligner/Changes
  0.15  2020-04-28
  - POD documentation cleanups - avoid using PodWeaver.
  - Thanks to "[Tux]"
  - The License is ISC.
  0.14  2020-04-28
  - Port dist.ini to @SHLOMIF, thus avoiding author tests in t/*.t.
* Thu May  5 2016 coolo@suse.com
- updated to 0.13
  see /usr/share/doc/packages/perl-Text-Aligner/Changes
  0.13  2016-04-17
  - Eliminate a warning "Negative repeat count does nothing" in recent
    perl5s in the test suite.
  - https://rt.cpan.org/Ticket/Display.html?id=113841
  - Thanks to KENTNL for the report and SREZIC for some guidance.
* Tue Feb 10 2015 coolo@suse.com
- updated to 0.12
  - Relicensed under the ISC license (with ANNO's permission).
  - Better documentation.
  0.11  2014-10-10
  - More meaningful README.
  - https://rt.cpan.org/Public/Bug/Display.html?id=99412
  - Thanks to MITHALDU for the report.
* Tue Mar  4 2014 tchvatal@suse.com
- Clean up with spec-cleaner
- Version bump to 0.10:
  * update download url
  * Now requiring Term::ANSIColor version 2.02.
  * Remove some *~ files.
  * Convert to Dist-Zilla / dist.ini for better CPANTS Kwalitee.
  * Various changes were involved.
  * Correct typos.
* Tue Apr 26 2011 coolo@opensuse.org
- updated to 0.07
  One colorskip-dependent test moved into skip block as per rt. #61276
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Aug 29 2010 pascal.bleser@opensuse.org
- initial package (0.06)
